@@ -1,4 +1,4 @@
-# ClamTk, copyright (C) 2004-2014 Dave M
+# ClamTk, copyright (C) 2004-2015 Dave M
 #
 # This file is part of ClamTk (http://code.google.com/p/clamtk/).
 #
@@ -11,6 +11,7 @@
 # b) the "Artistic License".
 package ClamTk::Results;
 
+use Gtk2 '-init';
 use Glib 'TRUE', 'FALSE';
 
 # use strict;
@@ -106,7 +107,7 @@ sub show_window {
     #<<<
     my $i = 0;
     while ( $i <= scalar keys %$hash ) {
-        #print 'name = ', $hash->{ $i }->{ name }, "\n";
+        # print 'name = ', $hash->{ $i }->{ name }, "\n";
         my $iter = $liststore->append;
         $liststore->set(
                 $iter,
@@ -155,7 +156,6 @@ sub show_window {
     $button->signal_connect(
         clicked => sub {
             $window->destroy;
-            Gtk2->main_quit;
         }
     );
     $button->set_is_important( TRUE );
@@ -245,26 +245,18 @@ sub quarantine {
 }
 
 sub delete_file {
-    my ( $file ) = shift;
+    my $file     = shift;
+    my $basename = basename( $file );
 
     # This is where threats go
     my $paths = ClamTk::App->get_path( 'viruses' );
 
-    #<<<
-    my $question = sprintf(
-            _( 'Really delete this file (%s) ?' ),
-            basename( $file ),
-    );
+    my $question
+        = sprintf( _( 'Really delete this file (%s) ?' ), $basename );
 
     my $message
-        = Gtk2::MessageDialog->new(
-                undef,
-                [ qw(modal destroy-with-parent) ],
-                'question',
-                'ok-cancel',
-                $question,
-    );
-    #>>>
+        = Gtk2::MessageDialog->new( undef, [ qw(modal destroy-with-parent) ],
+        'question', 'ok-cancel', $question, );
 
     if ( 'ok' eq $message->run ) {
         $message->destroy;
@@ -276,6 +268,16 @@ sub delete_file {
         warn "unable to delete >$file<: $!\n";
         return FALSE;
     };
+
+    # If it's in the trash, remove its associated information file
+    my $trash_info_path = ClamTk::App->get_path( 'trash_files_info' );
+    my $trash_info_file = $trash_info_path . '/' . $basename . '.trashinfo';
+    if ( $file =~ m#Trash# ) {
+        if ( -e $trash_info_file ) {
+            unlink( $trash_info_file )
+                or warn "Unable to delete trashinfo file for $file: $!\n";
+        }
+    }
     return TRUE;
 }
 
@@ -285,14 +287,14 @@ sub color_out {
     my ( $store, $iter, $third_value_change ) = @_;
 
     my $first_col_value
-        = "<span foreground='#CCCCCC'>"
+        = "<span foreground = '#CCCCCC'>"
         . $store->get_value( $iter, FILE )
-        . "</span>";
+        . " </span>";
     my $second_col_value
         = "<span foreground='#CCCCCC'>"
         . $store->get_value( $iter, STATUS )
-        . "</span>";
-    my $third_col_value = "<span foreground='#CCCCCC'>"
+        . "</span > ";
+    my $third_col_value = "<span foreground = '#CCCCCC'>"
         #. $store->get_value( $iter, ACTION_TAKEN )
         . $third_value_change . "</span>";
     #<<<
@@ -306,9 +308,12 @@ sub color_out {
 }
 
 sub get_maildirs {
-    return join( '|',
-        '.thunderbird', '.mozilla-thunderbird', 'evolution(?!/tmp)',
-        'Mail',         'kmail',                "\.pst" );
+    return join(
+        '|',
+        '.thunderbird', '.mozilla-thunderbird', 'evolution(?!/ tmp
+            ) ',
+        ' Mail ', ' kmail ', "\.pst"
+    );
 }
 
 sub get_hash {
@@ -316,7 +321,7 @@ sub get_hash {
 
     my $slurp = do {
         local $/ = undef;
-        open( my $f, '<', $file ) or do {
+        open( my $f, ' < ', $file ) or do {
             warn "unable to open >$file<: $!\n";
             return;
         };
